require File.join(File.dirname(__FILE__), %w[spec_helper])

require 'texzip'
require 'tempfile'

def init_env
  Dir.chdir(File.dirname(__FILE__))
end

describe TeXzip, 'on creation' do
  before do
    init_env
  end

  it 'should fail if the file does not exist' do
    expect { TeXzip::Project.new(File.join('dummy', 'nofile.tex')) }.to raise_error(/find file/)
  end

  it 'should not fail if the file exists' do
    expect { TeXzip::Project.new(File.join('dummy', 'root-file.tex')) }.not_to raise_error
  end
end

describe TeXzip, 'after creation' do
  before do
    init_env
    @tex_file = TeXzip::Project.new('dummy/root-file.tex')
  end

  it 'should return its correct path' do
    expect(@tex_file.master_file).to eq(Pathname.new('dummy/root-file.tex').expand_path)
  end

  it 'should return a list of included sub-files' do
    expect(@tex_file.tex_files.map(&:path).sort).to eq(%w(dummy/root-file.tex
                                                          dummy/chapter1.tex
                                                          dummy/chapter2.tex
                                                          dummy/chapter3/chapter3.tex
                                                          dummy/chapter3/chapter3.1.tex
                                                          dummy/chapter3/chapter3.2.tex
                                                          dummy/chapter4.tex).map{|p| Pathname.new(p).expand_path}.sort)
  end

  it 'should return a list of used bibtex files' do
    expect(@tex_file.bib_files.map(&:path).sort).to eq(%w(dummy/bib1.bib dummy/bib2.bib).map{|p| Pathname.new(p).expand_path}.sort)
  end

  it 'should return a list of used citations' do
    expect(@tex_file.cites.sort).to eq(%w( cite1 cite2 cite3 cite4 cite5 ).sort)
  end
end
